aboutsummaryrefslogtreecommitdiff
path: root/src/backend/taler-merchant-httpd.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/backend/taler-merchant-httpd.h')
-rw-r--r--src/backend/taler-merchant-httpd.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/backend/taler-merchant-httpd.h b/src/backend/taler-merchant-httpd.h
index 3594c01f..2ca3c20b 100644
--- a/src/backend/taler-merchant-httpd.h
+++ b/src/backend/taler-merchant-httpd.h
@@ -179,10 +179,10 @@ extern struct TALER_MERCHANTDB_Plugin *db;
/**
* If the frontend does NOT specify an execution date, how long should
* we tell the exchange to wait to aggregate transactions before
* executing? This delay is added to the current time when we
* generate the advisory execution time for the exchange.
*/
-extern struct GNUNET_TIME_Relative edate_delay;
+extern struct GNUNET_TIME_Relative wire_transfer_delay;
/**
* Kick MHD to run now, to be called after MHD_resume_connection().
@@ -179,10 +179,10 @@ extern struct TALER_MERCHANTDB_Plugin *db;
* If the frontend does NOT specify an execution date, how long should
* we tell the exchange to wait to aggregate transactions before
- * executing? This delay is added to the current time when we
- * generate the advisory execution time for the exchange.
+ * executing the wire transfer? This delay is added to the current
+ * time when we generate the advisory execution time for the exchange.
*/